 function ifo = IFOModel_L1_AplusProj
  % Modified GWINC model with aLIGO-linke parameters
  % and freqeuency dependent squeezing
  
  % start with base model
  ifo = IFOModel;
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Adjust IFO parameters
  
  % Set laser power
  ifo.Laser.Power = 125;
  ifo.Optics.Loss = 40e-6;  
  
  ifo.Optics.BSLoss  = 0.5e-3; %Recycling gain = 40
  ifo.Optics.PhotoDetectorEfficiency  = 0.9 % Photodiode/OMC/Faraday/Mode-matching

  ifo.Optics.SRM.Transmittance  = 0.325;   % Transmittance of SRM    
  ifo.Optics.SRM.Tunephase = 0;            % SRM tuning
  ifo.Optics.Quadrature.dc = 90 * pi/180;  % demod/detection/homodyne phase pi/2  

  
  % add Newtonian Noise cancellation
  ifo.Seismic.Omicron = 1;  
  
  ifo = precompIFO(ifo, true);
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Squeezer Parameters
  
  % Define the squee*pizing you want:
  %   None = ignore the squeezer settings
  %   Freq Independent = nothing special (no filter cavties)
  %   Freq Dependent = applies the specified filter cavites
  ifo.Squeezer.Type = 'Freq Dependent';
  ifo.Squeezer.AmplitudedB = 12;           % SQZ amplitude [dB]
  ifo.Squeezer.SQZAngle = 0*pi/180;        % SQZ phase [radians]
  
  ifo.Squeezer.InjectionLoss = 0.05;       % power loss after squeezer
  
  % Parameters for frequency dependent squeezing
  fcParams.L = 300;           % cavity length
  fcParams.Lrt = 60e-6;        % round-trip loss in the cavity
  fcParams.Te = 1e-6;          % end mirror trasmission
  fcParams.Rot = deg2rad(0);   % phase rotation after cavity (why?)
  
  % compute input mirror transmission and detuning
  fcParams = computeFCParams(ifo, fcParams);
  
  ifo.Squeezer.FilterCavity = fcParams;   % put in IFO struct
end
